var myRecorder, myRecorderStatus;

var clientStoreStatusListener;

var serverIP = "10.20.65.34",
    serverPort = "31337",
    endpoint = "/PRServletEndPoint",
    accountID = "defaultAccountId";

function clearOutput() {
    var d = document.getElementById('results');
    d.innerHTML = "";
}


function initClientStore() {
    var accountPassword = "defaultPassword",

        configureClientStore = function () {
            window.launchbox.PRPC.ClientStore.configure({
                url: 'http://' + serverIP + ':' + serverPort + endpoint,// Client Store configuration parameters
                reportChangesForTypes: [{"data": "data"}],
                sessionTimeout: '100',
                version: 2
            });

        },
        openAccountCallback = {
            onFailure: function (error) {
                console.log("Error when opening an account: " + JSON.stringify(error));

            },
            onSuccess: function (clientAccountID) {
                console.log("Add account: success");
                configureClientStore(); //Configuring the Client Store while executing onSuccess callback
            }
        },
        addAccountCallback = {
            onFailure: function (error) {
                console.log("Error when creating an account: " + JSON.stringify(error));

            },

            onSuccess: function (clientAccountID) {
                console.log("Open account: success");
                launchbox.AccountManager.openAccount(accountID, accountPassword, openAccountCallback);//Opening a new account
            }
        };

    launchbox.AccountManager.addAccount(accountID, accountPassword, addAccountCallback); //Adding a new account
}

var onStatusChangedHandler = function (status, error) {
    myRecorderStatus = status;
    console.log("onStatusChangedHandler: ");
    console.log(status);
    if (error !== undefined) {
        console.log("onStatusChangedHandler error: ");
        console.log(error.name + " : " + error.message);
    }
};

function createRecorder() {
    var caseId = "CASE_ID";
    console.log(caseId);
    launchbox.PRPC.LocationRecorder.recorder(caseId) //Creating new recorder with a given 'id'.
        .then(function (recorder) {
            myRecorder = recorder;
            myRecorder.onStatusChanged.bind(onStatusChangedHandler);//Location recorder status
            console.log("recorder: " + JSON.stringify(recorder));

            console.log("Obtained a recorder instance with 'id': ");
            console.log(recorder.identifier);
        }).catch(function (error) {
            console.log(JSON.stringify(error));
        });
}

function getAvailableRecorders() {
    launchbox.PRPC.LocationRecorder.availableRecorders()//Retrieving a list of existing recorder instances
        .then(function (dictionary) {
            console.log("dictionary: " + JSON.stringify(dictionary));
            console.log("Available recorder ids: ");
            console.log(Object.keys(dictionary));
            if (dictionary.foo !== undefined) {
                var recorder = dictionary.foo;
            }
        });
}

function configureTracker() {//Configuring an instance of a 'Recorder'

    // When you want to use a custom configuration:
    // 1. Create the 'Configuration' object 
    var configuration = new launchbox.PRPC.LocationRecorder.Configuration(); //

    // 2. Modify the properties according to your needs:  
    // - High accuracy toggle. If set to 'true' (default) a recorder tries to retrieve locations with the best accuracy, at the expense of battery drainage.
    configuration.enableHighAccuracy = true;

    // - A minimum distance (in meters) a device must move horizontally before an update event is generated.
    // Defaults to 5.0 meters.
    configuration.distanceFilter = 0;

    // - A minimum time interval (in seconds) which must have passed between two location update events.
    // Defaults to 10 seconds.
    configuration.minimalLocationRetrievalInterval = 2;

    // - A map of custom attributes. By default it is an empty object.
    configuration.customAttributes = {'foo': 42, 'bar': false};

    // A time interval (in seconds) after which the recorder automatically stops collecting new locations.
    // By default it is set to 'Infinity'.
    configuration.workingPeriod = 30;

    // 3. Pass the configuration object to the recorder object.  
    myRecorder.configuration = configuration;

    console.log(JSON.stringify(configuration));
}

function startRecorder() {
    myRecorder.start() //Starts the recording of location data.
        .then(function () {
            console.log("Recorder has started succesfully");
        }).catch(function (error) {
            console.log(error);
        });
}

function pauseRecorder() {
    myRecorder.pause() //Pauses the recording of location data.
        .then(function () {
            console.log("Recorder has paused recording.");
        }).catch(function (error) {
            console.log(error);
        });
}

function resumeRecorder() {
    myRecorder.resume() //Resumes the recording of location data after it was paused.
        .then(function () {
        console.log("Recorder has resumed recording.");
    }).catch(function (error) {
        console.log(error);
    });
}

function stopRecorder() {
    myRecorder.stop() //Stops the recording of location data.
        .then(function () {
        console.log("Recorder has stopped successfully.");
    }).catch(function (error) {
        console.log(error);
    });
}

function invalidateRecorder() {
    myRecorder.invalidate() //Invalidates the recording. Once the recorder is invalidated, it is no longer usable.
        .then(function () {
        console.log("Recorder has been invalidated successfully.");
    }).catch(function (error) {
        console.log(error);
    });
}

function unbindRecorderStatusChanged() {
    myRecorderStatus = "unknown";
    myRecorder.onStatusChanged.unbind(onStatusChangedHandler); //Stops the location recorder.
}

function displayRecorderStatus() {
    console.log("current recorder status: " + myRecorderStatus);
}